@@ -4,8 +4,9 @@ package Catalyst::Plugin::Authentication::Store::Htpasswd;
 
 use strict;
 use warnings;
+use MRO::Compat;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Catalyst::Plugin::Authentication::Store::Htpasswd::Backend;
 
@@ -18,7 +19,7 @@ sub setup {
         )
     );
 
-	$c->NEXT::setup(@_);
+    $c->maybe::next::method(@_);
 }
 
 __PACKAGE__;
